exchange Package — pwman3 0.6 documentation

### Navigation

- index
- modules |
- pwman3 0.6 documentation »

# exchange Package

## `importer` Module

A module to hold the importer class

class `pwman.exchange.importer.` `BaseImporter`

  Bases: `object`

  The base class which defines the action needed to import data to pwman database

class `pwman.exchange.importer.` `CSVImporter`(args, config, db)

  Bases: `pwman.exchange.importer.BaseImporter`

  A reference implementation which imports a CSV to the pwman database

  `run`(callback=<class 'pwman.ui.tools.CLICallback'>)

class `pwman.exchange.importer.` `Importer`(args, invoke=<class 'pwman.exchange.importer.CSVImporter'>)

  Bases: `object`

  The actual job runner which by default runs a csv importer instance. This could be changes by calling other instance which for example import from KeePass XML or other formats.

  `run`()

### Navigation

- index
- modules |
- pwman3 0.6 documentation »